@@ -22,37 +22,40 @@ from __future__ import annotations
 
 import copy
 import os
-import pathlib
 import zipfile
 from contextlib import suppress
 from dataclasses import dataclass
-from io import BytesIO
 from operator import attrgetter
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, cast
+from typing import TYPE_CHECKING, List
 from warnings import warn
 
 from lxml import etree
 from typing_extensions import Self
 
-from .attribute_register import XML2HTML_FORMATTER
-from .docx_context import collect_numFmts, collect_rels
-from .docx_text import TablesList, get_text, new_depth_collector
-from .merge_runs import merge_elems
+from docx2python import depth_collector
+from docx2python.attribute_register import XML2HTML_FORMATTER
+from docx2python.docx_context import NumIdAttrs, collect_numAttrs, collect_rels
+from docx2python.docx_text import get_file_content, new_depth_collector
+from docx2python.merge_runs import merge_elems
+
+ParsTable = List[List[List[List[depth_collector.Par]]]]
+TextTable = List[List[List[List[List[str]]]]]
 
 if TYPE_CHECKING:
     from io import BytesIO
+    from types import TracebackType
 
     from lxml.etree import _Element as EtreeElement  # type: ignore
 
-    from .depth_collector import DepthCollector
+    from docx2python.depth_collector import DepthCollector
 
 CONTENT_FILE_TYPES = {"officeDocument", "header", "footer", "footnotes", "endnotes"}
 
 
 @dataclass
 class File:
-    """The attribute dict of a file in the docx, plus cached data
+    """The attribute dict of a file in the docx, plus cached data.
 
     The docx lists internal files in various _rels files. Each will be specified with a
     dict of, e.g.::
@@ -73,8 +76,7 @@ class File:
     """
 
     def __init__(self, context: DocxReader, attribute_dict: dict[str, str]) -> None:
-        """
-        Point to container DocxContext instance and store attributes as properties.
+        """Point to container DocxContext instance and store attributes as properties.
 
         :param context: The DocxContent object holding this instance
         :param attribute_dict: Attributes of this file found in the rels, plus 'dir' as
@@ -82,7 +84,7 @@ class File:
         """
         self.context = context
         self.Id = str(attribute_dict["Id"])
-        self.Type = os.path.basename(attribute_dict["Type"])
+        self.Type = Path(attribute_dict["Type"]).name
         self.Target = attribute_dict["Target"]
         self.dir = attribute_dict["dir"]
 
@@ -94,7 +96,7 @@ class File:
         self.__depth_collector: None | DepthCollector = None
 
     def __repr__(self) -> str:
-        """File with self.path
+        """File with self.path.
 
         :return: String representation
         """
@@ -102,7 +104,7 @@ class File:
 
     @property
     def path(self) -> str:
-        """Infer path/to/xml/file from instance attributes
+        """Infer path/to/xml/file from instance attributes.
 
         :return: path to xml file
 
@@ -125,9 +127,9 @@ class File:
         if self.__path is not None:
             return self.__path
 
-        dirs = [os.path.dirname(x) for x in (self.dir, self.Target)]
+        dirs = [Path(x).parent.name for x in (self.dir, self.Target)]
         dirname = "/".join([x for x in dirs if x])
-        filename = os.path.basename(self.Target)
+        filename = Path(self.Target).name
         self.__path = f"{dirname}/{filename}"
         return self.__path
 
@@ -162,7 +164,7 @@ class File:
 
     @property
     def rels(self) -> dict[str, str]:
-        """rIds mapped to values
+        """Get rIds mapped to values.
 
         :return: dict of rIds mapped to values
 
@@ -220,7 +222,8 @@ class File:
                 warn(
                     "Attempt to merge consecutive elements in "
                     + f"{self.context.docx_filename} {self.path} resulted in "
-                    + f"{repr(ex)}. Moving on."
+                    + f"{ex!r}. Moving on.",
+                    stacklevel=2,
                 )
                 self.__root_element = root_
         self.__root_element = root
@@ -238,40 +241,52 @@ class File:
         return self.__depth_collector
 
     @property
-    def content(self) -> list[list[list[list[str]]]]:
-        """Text extracted into a 5-layer-deep nested list of strings.
+    def content(self) -> ParsTable:
+        """Text extracted into a 4-deep nested list of Par instances.
 
-        :return: Text extracted into a 5-layer-deep nested list of strings.
+        :return: [[[[Par]]]]
         """
         return self.get_content()
 
-    def get_content(
-        self, root: EtreeElement | None = None
-    ) -> list[list[list[list[str]]]]:
+    @property
+    def text(self) -> TextTable:
+        """Text extracted into a 5-deep list of strings [[[[[str]]]]].
+
+        :return: Text extracted into a nested list of strings [[[[[str]]]]]
         """
-        The same content as property 'content' with optional given root.
+        return self.get_text()
+
+    def get_content(self, root: EtreeElement | None = None) -> ParsTable:
+        """Return the same content as property 'content' with optional given root.
 
         :param root: Extract content of file from root down.
             If root is not given, return full content of file.
-        :return: Text extracted into a 5-layer-deep nested list of strings.
+        :return: Text extracted into [[[[Par]]]]
         """
         if root is None:
-            return cast(TablesList, self.depth_collector.tree)
-        return get_text(self, root)
+            return self.depth_collector.tree
+        return get_file_content(self, root)
+
+    def get_text(self, root: EtreeElement | None = None) -> TextTable:
+        """Return the same content as property 'text' with optional given root.
+
+        :param root: Extract content of file from root down.
+            If root is not given, return full content of file.
+        :return: Text extracted into [[[[[str]]]]]
+        """
+        return depth_collector.get_par_strings(self.get_content(root))
 
 
 @dataclass
 class DocxReader:
-    """
-    Hold File instances and decode information shared between them (e.g., numFmts)
-    """
+    """Hold File instances and decode info shared between them (e.g., numFmts)."""
 
     def __init__(
         self,
-        docx_filename: Path | str | BytesIO,
+        docx_filename: str | os.PathLike[str] | BytesIO,
+        *,
         html: bool = False,
-        paragraph_styles: bool = False,
-        duplicate_merged_cells: bool = False,
+        duplicate_merged_cells: bool = True,
     ) -> None:
         """Initialize DocxReader instance.
 
@@ -281,7 +296,6 @@ class DocxReader:
         :param duplicate_merged_cells: If True, duplicate text in merged cells.
         """
         self.docx_filename = docx_filename
-        self.do_pStyle = paragraph_styles
         self.duplicate_merged_cells = duplicate_merged_cells
 
         if html:
@@ -292,23 +306,22 @@ class DocxReader:
         # cached properties and a flag (__closed)
         self.__zipf: None | zipfile.ZipFile = None
         self.__files: None | list[File] = None
-        self.__numId2NumFmts: None | dict[str, list[str]] = None
+        self.__numId2Attrs: None | dict[str, list[NumIdAttrs]] = None
         self.__closed = False
 
     @property
     def zipf(self) -> zipfile.ZipFile:
-        """
-        Entire docx unzipped into bytes.
+        """Entire docx unzipped into bytes.
 
         :return: Entire docx unzipped into bytes.
         :raise ValueError: If DocxReader instance has been closed
         """
         if self.__closed:
-            raise ValueError("DocxReader instance has been closed.")
+            msg = "DocxReader instance has been closed."
+            raise ValueError(msg)
         if self.__zipf is None:
             self.__zipf = zipfile.ZipFile(self.docx_filename)
             return self.__zipf
-        assert self.__zipf is not None
         return self.__zipf
 
     def close(self):
@@ -326,9 +339,9 @@ class DocxReader:
 
     def __exit__(
         self,
-        exc_type: Any,  # None | Type[Exception], but py <= 3.9 doesn't like it.
-        exc_value: Any,  # None | Exception, but py <= 3.9 doesn't like it.
-        exc_traceback: Any,  # None | TracebackType, but py <= 3.9 doesn't like it.
+        exc_type: None | type[BaseException],
+        exc_value: None | BaseException,
+        exc_traceback: None | TracebackType,
     ) -> Self:
         """Close the zipfile.
 
@@ -341,8 +354,7 @@ class DocxReader:
 
     @property
     def files(self) -> list[File]:
-        """
-        Instantiate a File instance for every content file.
+        """Instantiate a File instance for every content file.
 
         :return: List of File instances, one per content file.
         """
@@ -351,14 +363,14 @@ class DocxReader:
 
         files: list[File] = []
         for k, v in collect_rels(self.zipf).items():
-            files += [File(self, {**x, "dir": os.path.dirname(k)}) for x in v]
+            dir_ = str(Path(k).parent)
+            files += [File(self, {**x, "dir": dir_}) for x in v]
         self.__files = files
         return self.__files
 
     @property
     def comments(self) -> list[EtreeElement]:
-        """
-        Comments from the document.
+        """Comments from the document.
 
         :return: Comments from the document.
         """
@@ -369,31 +381,29 @@ class DocxReader:
         return list(comment_file.root_element)
 
     @property
-    def numId2numFmts(self) -> dict[str, list[str]]:
-        """
-        numId referenced in xml to list of numFmt per indentation level
+    def numId2Attrs(self) -> dict[str, list[NumIdAttrs]]:
+        """Return numId referenced in xml to list of NumIdAttrs per indentation level.
 
-        :return: numId referenced in xml to list of numFmt per indentation level
+        :return: numId referenced in xml to list of NumIdAttrs per indentation level
 
-        See docstring for collect_numFmts
+        See docstring for collect_numAttrs
 
         Returns an empty dictionary if word/numbering.xml cannot be found.
         Ultimately, this will result in any lists (there should NOT be any lists if
         there is no word/numbering.xml) being "numbered" with "--".
         """
-        if self.__numId2NumFmts is not None:
-            return self.__numId2NumFmts
+        if self.__numId2Attrs is not None:
+            return self.__numId2Attrs
 
         try:
             numFmts_root = etree.fromstring(self.zipf.read("word/numbering.xml"))
-            self.__numId2NumFmts = collect_numFmts(numFmts_root)
+            self.__numId2Attrs = collect_numAttrs(numFmts_root)
         except KeyError:
-            self.__numId2NumFmts = {}
-        return self.__numId2NumFmts
+            self.__numId2Attrs = {}
+        return self.__numId2Attrs
 
     def file_of_type(self, type_: str) -> File:
-        """
-        Return file instance attrib Type='http://.../type_'. Warn if more than one.
+        """Return file instance attrib Type='http://.../type_'. Warn if more than one.
 
         :param type_: this package looks for any of
             ("header", "officeDocument", "footer", "footnotes", "endnotes")
@@ -403,7 +413,9 @@ class DocxReader:
         """
         files_of_type = self.files_of_type(type_)
         if len(files_of_type) > 1:
-            warn("Multiple files of type '{type_}' found. Returning first.")
+            warn(
+                "Multiple files of type '{type_}' found. Returning first.", stacklevel=2
+            )
         try:
             return files_of_type[0]
         except IndexError as exc:
@@ -413,8 +425,7 @@ class DocxReader:
             ) from exc
 
     def files_of_type(self, type_: str | None = None) -> list[File]:
-        """
-        File instances with attrib Type='http://.../type_'
+        """List File instances with attrib Type='http://.../type_'.
 
         :param type_: this package looks for any of
             ("header", "officeDocument", "footer", "footnotes", "endnotes", "comments")
@@ -422,26 +433,20 @@ class DocxReader:
             types.
         :return: File instances of the requested type, sorted by path
         """
-        if type_ is None:
-            types = CONTENT_FILE_TYPES
-        else:
-            types = {type_}
-
+        types = CONTENT_FILE_TYPES if type_ is None else {type_}
         return sorted(
             (x for x in self.files if x.Type in types), key=attrgetter("path")
         )
 
     def content_files(self) -> list[File]:
-        """
-        Content files (contain displayed text) inside the docx.
+        """List content files (contain displayed text) inside the docx.
 
         :return: File instances of context files, sorted by path
         """
         return self.files_of_type()
 
-    def save(self, filename: Path | str) -> None:
-        """
-        Save the (presumably altered) xml.
+    def save(self, filename: str | os.PathLike[str]) -> None:
+        """Save the (presumably altered) xml.
 
         :param filename: path to output file (presumably *.docx)
 
@@ -455,9 +460,10 @@ class DocxReader:
             for file in content_files:
                 zout.writestr(file.path, etree.tostring(file.root_element))
 
-    def pull_image_files(self, image_directory: str | None = None) -> dict[str, bytes]:
-        """
-        Copy images from zip file.
+    def pull_image_files(
+        self, image_directory: str | os.PathLike[str] | None = None
+    ) -> dict[str, bytes]:
+        """Copy images from zip file.
 
         :param image_directory: optional destination for copied images
         :return: Image names mapped to images in binary format.
@@ -473,11 +479,12 @@ class DocxReader:
         images: dict[str, bytes] = {}
         for image in self.files_of_type("image"):
             with suppress(KeyError):
-                images[os.path.basename(image.Target)] = self.zipf.read(image.path)
+                images[Path(image.Target).name] = self.zipf.read(image.path)
         if image_directory is not None:
-            pathlib.Path(image_directory).mkdir(parents=True, exist_ok=True)
+            image_directory = Path(image_directory)
+            image_directory.mkdir(parents=True, exist_ok=True)
             for file, image_bytes in images.items():
-                with open(os.path.join(image_directory, file), "wb") as image_copy:
+                with (image_directory / file).open("wb") as image_copy:
                     _ = image_copy.write(image_bytes)
         return images
 
@@ -487,8 +494,7 @@ def _copy_but(
     out_zip: zipfile.ZipFile,
     exclusions: set[str] | None = None,
 ) -> None:
-    """
-    Copy every file in a docx except those listed in exclusions.
+    """Copy every file in a docx except those listed in exclusions.
 
     :param in_zip: zipfile of origin xml file
     :param out_zip: zipfile of destination xml file
