@@ -13,8 +13,7 @@ Docx2Python previously ignored <w:br/> elements:
 
 from docx2python import docx2python
 from docx2python.iterators import iter_paragraphs
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 
 class TestSoftLineBreaks:
